pub struct HydePreprocessor<G: HypotheticalGenerator> { /* private fields */ }Expand description
HyDE (Hypothetical Document Embeddings) preprocessor.
Instead of searching with the query directly, HyDE generates a hypothetical document that would answer the query, then uses that for retrieval. This can improve semantic matching by generating content in the same “language” as the documents being searched.
Implementations
Sourceimpl<G: HypotheticalGenerator> HydePreprocessor<G>
impl<G: HypotheticalGenerator> HydePreprocessor<G>
Sourcepub fn with_original_query(self, include: bool) -> Self
pub fn with_original_query(self, include: bool) -> Self
Include the original query alongside the hypothetical document.